/***************************************************************************
                          kmyradio.cpp  -  description
                             -------------------
    begin                : Mon Apr  2 21:00:20 EDT 2001
    copyright            : (C) 2001 by Chuck Ross
    email                : cross37@earthlink.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kmyradio.h"

#include <stdlib.h>
#include <unistd.h>
#include <qpushbutton.h>
#include <qtimer.h>
#include <qlineedit.h>
#include <qpalette.h>
#include <kcolorbutton.h>
#include <kapp.h>
#include <kmessagebox.h>

KMyRadio::KMyRadio(QWidget *parent, const char *name) : kmyradiointerface(parent, name)
{
  tuner = new radiotuner("/dev/radio");
  tuner->setRangeCheck(false);

  config = new KSimpleConfig("kmyradiorc");
  if (config->hasKey("defaults"))
    readSettings();
  else
    defaultSettings();

  applySettings();

  settings = new SettingsDlg(0,0,true);

  preset(0);

  QTimer *t = new QTimer( this );
  connect( t, SIGNAL(timeout()), SLOT(fasttune()) );
  t->start(50, FALSE );

  Volume = 0;
  LastVolume = 0;

  QObject::connect((QObject*)VolumeSlider, SIGNAL(valueChanged(int)), this, SLOT(setVolume(int)));
  QObject::connect((QObject*)Preset1, SIGNAL(clicked()), this, SLOT(preset1()));
  QObject::connect((QObject*)Preset2, SIGNAL(clicked()), this, SLOT(preset2()));
  QObject::connect((QObject*)Preset3, SIGNAL(clicked()), this, SLOT(preset3()));
  QObject::connect((QObject*)Preset4, SIGNAL(clicked()), this, SLOT(preset4()));
  QObject::connect((QObject*)Preset5, SIGNAL(clicked()), this, SLOT(preset5()));
  QObject::connect((QObject*)Preset6, SIGNAL(clicked()), this, SLOT(preset6()));
  QObject::connect((QObject*)SetButton, SIGNAL(clicked()), this, SLOT(startSettingsDialog()));
  QObject::connect((QObject*)PowerButton, SIGNAL(clicked()), this, SLOT(quit()));

//  QObject::connect((QObject*)TuneDown, SIGNAL(clicked()), this, SLOT(decStation()));
}

KMyRadio::~KMyRadio()
{
  tuner->mute(true);
}

void KMyRadio::setStation() {

  char buf[10];
  StationLabel->setText(gcvt(frequency, 5, (char*)&buf));
  tuner->setFreq(frequency);
  return;
}

void KMyRadio::incStation() {

  if ( (frequency + 0.2) <= tuner->getFloatHighFreq()) {
    frequency += 0.2;
    setStation();
  }

}

void KMyRadio::decStation() {

  if ( (frequency - 0.2) >= tuner->getFloatLowFreq()) {
    frequency -= 0.2;
    setStation();
  }

}


void KMyRadio::fasttune() {

  if (TuneUp->isDown())
    incStation();
  if (TuneDown->isDown())
    decStation();
  if (Volume != LastVolume) {
    tuner->setVolume(Volume);
    LastVolume = Volume;
  }

}

void KMyRadio::setVolume(int v) {

  Volume = v;

  //tuner->setVolume(v);

}

void KMyRadio::preset(int p) {

  frequency = strtod(Stations[p], NULL);
  DescriptionLabel->setText(Descriptions[p]);
  setStation();

}

void KMyRadio::preset1() {
  preset(0);
}

void KMyRadio::preset2() {
  preset(1);
}


void KMyRadio::preset3() {
  preset(2);
}


void KMyRadio::preset4() {
  preset(3);
}

void KMyRadio::preset5() {
  preset(4);
}

void KMyRadio::preset6() {
  preset(5);
}


void KMyRadio::readSettings() {

  Stations[0] = config->readEntry("p1");
  Stations[1] = config->readEntry("p2");
  Stations[2] = config->readEntry("p3");
  Stations[3] = config->readEntry("p4");
  Stations[4] = config->readEntry("p5");
  Stations[5] = config->readEntry("p6");

  Descriptions[0] = config->readEntry("d1");
  Descriptions[1] = config->readEntry("d2");
  Descriptions[2] = config->readEntry("d3");
  Descriptions[3] = config->readEntry("d4");
  Descriptions[4] = config->readEntry("d5");
  Descriptions[5] = config->readEntry("d6");

  StationFont = config->readFontEntry("stationfont");
     DescFont = config->readFontEntry("descriptionfont");

     BackColor = config->readColorEntry("backcolor");
  DisplayColor = config->readColorEntry("displaycolor");
  StationColor = config->readColorEntry("stationcolor");
     DescColor = config->readColorEntry("desccolor");
   ButtonColor = config->readColorEntry("buttoncolor");

  DeviceName = config->readEntry("device");

}

void KMyRadio::writeSettings(bool defaultset = false) {
  if (defaultset)
    config->writeEntry("defaults", 1);
  else
    config->writeEntry("defaults", 0);

  config->writeEntry("p1", Stations[0]);
  config->writeEntry("p2", Stations[1]);
  config->writeEntry("p3", Stations[2]);
  config->writeEntry("p4", Stations[3]);
  config->writeEntry("p5", Stations[4]);
  config->writeEntry("p6", Stations[5]);

  config->writeEntry("d1", Descriptions[0]);
  config->writeEntry("d2", Descriptions[1]);
  config->writeEntry("d3", Descriptions[2]);
  config->writeEntry("d4", Descriptions[3]);
  config->writeEntry("d5", Descriptions[4]);
  config->writeEntry("d6", Descriptions[5]);

  //config->writeEntry("stationfont", StationLabel->font());
  //config->writeEntry("descriptionfont", DescriptionLabel->font());

  config->writeEntry("stationfont", StationFont);
  config->writeEntry("descriptionfont", DescFont);

  config->writeEntry("backcolor", BackColor);
  config->writeEntry("displaycolor", DisplayColor);
  config->writeEntry("stationcolor", StationColor);
  config->writeEntry("desccolor", DescColor);
  config->writeEntry("buttoncolor", ButtonColor);

  config->writeEntry("device", DeviceName);

  config->sync();

}

void KMyRadio::defaultSettings() {

  Stations[0] = "92.3";
  Descriptions[0] = "K-ROCK";

  Stations[1] = "102.7";
  Descriptions[1] = "WNEW";

  Stations[2] = "105.5";
  Descriptions[2] = "WDHA";

  Stations[3] = "104.3";
  Descriptions[3] = "WAXQ";

  Stations[4] = "89.5";
  Descriptions[4] = "WSOU";

  Stations[5] = "99.5";
  Descriptions[5] = "WBAI - OTH Tue 8pm";

  StationFont = StationLabel->font();
  DescFont = DescriptionLabel->font();

  BackColor = QColor(129,129,129);
  ButtonColor = QColor(214,214,214);
  DescColor = QColor(105,6,6);
  DisplayColor = QColor(197,197,197);
  StationColor = QColor(0,0,0);

  DeviceName = "/dev/radio";

  writeSettings(true);
}

void KMyRadio::initSettings() {

  settings->P1Station->setText(Stations[0]);
  settings->P2Station->setText(Stations[1]);
  settings->P3Station->setText(Stations[2]);
  settings->P4Station->setText(Stations[3]);
  settings->P5Station->setText(Stations[4]);
  settings->P6Station->setText(Stations[5]);

  settings->P1Desc->setText(Descriptions[0]);
  settings->P2Desc->setText(Descriptions[1]);
  settings->P3Desc->setText(Descriptions[2]);
  settings->P4Desc->setText(Descriptions[3]);
  settings->P5Desc->setText(Descriptions[4]);
  settings->P6Desc->setText(Descriptions[5]);

  settings->StationFont = StationFont;
  settings->DescFont = DescFont;
  settings->StationFontButton->setText(StationFont.family());
  settings->DescFontButton->setText(DescFont.family());

  settings->BackColorButton->setColor(BackColor);
  settings->ButtonColorButton->setColor(ButtonColor);
  settings->DisplayColorButton->setColor(DisplayColor);
  settings->StationColorButton->setColor(StationColor);
  settings->DescColorButton->setColor(DescColor);

  settings->DeviceLine->setText(DeviceName);


}

void KMyRadio::applySettings() {

  StationLabel->setFont(StationFont);
  DescriptionLabel->setFont(DescFont);

  QPalette pal = palette();
  QColorGroup cg = pal.active();

  cg.setColor(QColorGroup::Background, BackColor);
  cg.setColor(QColorGroup::Button, ButtonColor);

  pal.setActive(cg);
  pal.setInactive(cg);
  setPalette(pal);

  pal = StationLabel->palette();
  cg = pal.active();

  cg.setColor(QColorGroup::Background, DisplayColor);
  cg.setColor(QColorGroup::Foreground, StationColor);

  pal.setActive(cg);
  pal.setInactive(cg);
  StationLabel->setPalette(pal);
  DescriptionLabel->setPalette(pal);

  pal = DescriptionLabel->palette();
  cg = pal.active();

  cg.setColor(QColorGroup::Foreground, DescColor);

  pal.setActive(cg);
  pal.setInactive(cg);
  DescriptionLabel->setPalette(pal);

}


void KMyRadio::startSettingsDialog() {

  initSettings();

  if (settings->exec()) {

    Stations[0] = settings->P1Station->text();
    Stations[1] = settings->P2Station->text();
    Stations[2] = settings->P3Station->text();
    Stations[3] = settings->P4Station->text();
    Stations[4] = settings->P5Station->text();
    Stations[5] = settings->P6Station->text();

    Descriptions[0] = settings->P1Desc->text();
    Descriptions[1] = settings->P2Desc->text();
    Descriptions[2] = settings->P3Desc->text();
    Descriptions[3] = settings->P4Desc->text();
    Descriptions[4] = settings->P5Desc->text();
    Descriptions[5] = settings->P6Desc->text();

    StationFont = settings->StationFont;
    DescFont = settings->DescFont;

    BackColor = settings->BackColorButton->color();
    StationColor = settings->StationColorButton->color();
    DescColor = settings->DescColorButton->color();
    DisplayColor = settings->DisplayColorButton->color();
    ButtonColor = settings->ButtonColorButton->color();

    DeviceName = settings->DeviceLine->text();

    applySettings();
    writeSettings();

  }

}

void KMyRadio::quit() {

  int answer = KMessageBox::warningYesNoCancel(0, "Leave the radio on?", "Question");
  if (answer == KMessageBox::Yes)
    kapp->quit();
  if (answer == KMessageBox::No) {
    tuner->mute(true);
    kapp->quit();
  }
}

