/***************************************************************************
                          radiotuner.cpp  -  description
                             -------------------
    begin                : Sun Apr 1 2001
    copyright            : (C) 2001 by Chuck Ross
    email                : cross37@earthlink.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <iostream.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include "radiotuner.h"

radiotuner::radiotuner(){
  int result = init("/dev/radio");
}

radiotuner::~radiotuner(){
  close(filedesc);
}

radiotuner::radiotuner(char* devname) {
  init(devname);
}

int radiotuner::init(char* devname){

  HAVE_VID_CAP = false;
  HAVE_TUNE_CAP = false;
  HAVE_AUDIO_CAP = false;
  FREQ_RANGE_CHECK = true;

  status = ERR_NONE;

  tunecap.tuner = 0;
  filedesc = open(devname, O_RDWR);
  if (filedesc < 0) {
    cout << "Cannot open device " << devname << "\n";
    return -1;
  }
  getVideoCapabilities();
  getTunerCapabilities();
  getAudioCapabilities();

  if (tunecap.flags & VIDEO_TUNER_LOW)
    FREQ_DIVIDE = 1000;
  else
    FREQ_DIVIDE = 1.0;


  return 0;
}

void radiotuner::getVideoCapabilities() {

  if (ioctl(filedesc, VIDIOCGCAP, &vidcap)) {
    HAVE_VID_CAP = false;
  }
  else {
    HAVE_VID_CAP = true;
  }
}

void radiotuner::getTunerCapabilities() {

  if (ioctl(filedesc, VIDIOCGTUNER, &tunecap)) {
    HAVE_TUNE_CAP = false;
  }
  else {
    HAVE_TUNE_CAP = true;
  }
}

void radiotuner::getAudioCapabilities() {

  if (ioctl(filedesc, VIDIOCGAUDIO, &audcap)) {
    HAVE_AUDIO_CAP = false;
  }
  else {
    HAVE_AUDIO_CAP = true;
  }
}

void radiotuner::setAudioCapabilities() {

  if (ioctl(filedesc, VIDIOCSAUDIO, &audcap))
    HAVE_AUDIO_CAP = ERR_AUDIO_SET;
  else
    HAVE_AUDIO_CAP = ERR_NONE;

}


float radiotuner::getFreq() {
  float freq;
  unsigned long intfreq;

  if (ioctl(filedesc, VIDIOCGFREQ, &intfreq))
    freq = 0.0;
  else
    freq = (intfreq) * 0.0625 / FREQ_DIVIDE;

  return freq;
}

int radiotuner::setFreq(float freq) {

  unsigned long intfreq;

  intfreq = (freq / 0.0625 * FREQ_DIVIDE)+1;

  if (FREQ_RANGE_CHECK) {
    if (HAVE_TUNE_CAP and ((freq < getFloatLowFreq()) or (freq > getFloatHighFreq()))) {
      return ERR_RANGE;
    }
  }

  if (ioctl(filedesc, VIDIOCSFREQ, &intfreq))
    return ERR_RANGE;
  else
    return ERR_NONE;

}

void radiotuner::setRangeCheck(bool b) {
  FREQ_RANGE_CHECK = b;
  return;
}

float radiotuner::getFloatLowFreq() {
  return getIntLowFreq() * 0.0625 / FREQ_DIVIDE;
}

float radiotuner::getFloatHighFreq() {
  return getIntHighFreq() * 0.0625 / FREQ_DIVIDE;
}

unsigned long radiotuner::getIntLowFreq() {

  if (HAVE_TUNE_CAP)
    return tunecap.rangelow;
  else
    return 0;
}

unsigned long radiotuner::getIntHighFreq() {
  if (HAVE_TUNE_CAP)
    return tunecap.rangehigh;
  else
    return -1;
}

int radiotuner::getVolume() {
  getAudioCapabilities();
  return audcap.volume;
}

void radiotuner::setVolume(int v) {
  audcap.volume = v;
  setAudioCapabilities();
}

bool radiotuner::mute() {
  getAudioCapabilities();
  if (audcap.flags & VIDEO_AUDIO_MUTE)
    return true;
  else
    return false;
}

void radiotuner::mute(bool m) {

  if (m) {
    if ((audcap.flags & VIDEO_AUDIO_MUTABLE) and (!mute())) {
      audcap.flags += VIDEO_AUDIO_MUTE;
      setAudioCapabilities();
    }
  }
  else {
    if ((audcap.flags & VIDEO_AUDIO_MUTABLE) and (mute())) {
      audcap.flags -= VIDEO_AUDIO_MUTE;
      setAudioCapabilities();
    }
  }
}




