/***************************************************************************
                          kmyradio.cpp  -  description
                             -------------------
    begin                : Mon Apr 16 21:00:20 EDT 2001
    copyright            : (C) 2001 by Chuck Ross
    email                : cross37@earthlink.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kmyradio.h"
#include "inputdialog.h"
#include "mixer.h"

#include <stdlib.h>
#include <unistd.h>
#include <qpushbutton.h>
#include <qtimer.h>
#include <qlineedit.h>
#include <qpalette.h>
#include <kcolorbutton.h>
#include <kapp.h>
#include <kmessagebox.h>
#include <qcombobox.h>
#include <qcheckbox.h>
#include <qradiobutton.h>

KMyRadio::KMyRadio(QWidget *parent, const char *name) : kmyradiointerface(parent, name)
{
  tuner = new radiotuner("/dev/radio");
  tuner->setRangeCheck(false);
  mix = new Mixer("/dev/mixer");
  volumedevice = V4L_VOLUME;
  VolumeControlName = "V4L";

  settings = new SettingsDlg(0,0,true);
  int x;

  // Set up a list of valid mixer channels
  char *mixnameschar[] = SOUND_DEVICE_LABELS;
  for (x=0; x<SOUND_MIXER_NRDEVICES; x++) {
    mixnames[x] = mixnameschar[x];
    mixnames[x] = mixnames[x].simplifyWhiteSpace();
    if (mix->devmask & (1<<x))
      mixlist << mixnames[x];
  }

  isPreset = false;
  config = new KSimpleConfig("kmyradiorc");
  if (config->hasKey("defaults"))
    readSettings();
  else
    defaultSettings();
  applySettings();

  for (x=0; x<6; x++)
    PresetWatch[x] = 0;

  preset(0);
  Bank = 1;

  // This timer emits a signal every 1/4 second, when the signal is caught,
  // the volume is compared to the previously known volume.  If they are different,
  // the volume is changed.  (It's called fasttune because it used to handle the
  // tuneup/tunedown buttons.)
  QTimer *t1 = new QTimer( this );
  connect( t1, SIGNAL(timeout()), SLOT(fasttune()) );
  t1->start(250, FALSE );

  // This timer emits a signal every 3/4 second.  the slot which catches the signal
  // handles setting new presets.
  QTimer *t2 = new QTimer( this );
  connect( t2, SIGNAL(timeout()), SLOT(handlePresets()) );
  t2->start(750, FALSE );

  Volume = 0;
  LastVolume = 0;

  TuneUp->setAutoRepeat(true);
  TuneDown->setAutoRepeat(true);


  QObject::connect((QObject*)VolumeSlider, SIGNAL(valueChanged(int)), this, SLOT(setVolume(int)));
  QObject::connect((QObject*)Preset1, SIGNAL(clicked()), this, SLOT(preset1()));
  QObject::connect((QObject*)Preset2, SIGNAL(clicked()), this, SLOT(preset2()));
  QObject::connect((QObject*)Preset3, SIGNAL(clicked()), this, SLOT(preset3()));
  QObject::connect((QObject*)Preset4, SIGNAL(clicked()), this, SLOT(preset4()));
  QObject::connect((QObject*)Preset5, SIGNAL(clicked()), this, SLOT(preset5()));
  QObject::connect((QObject*)Preset6, SIGNAL(clicked()), this, SLOT(preset6()));
  QObject::connect((QObject*)SetButton, SIGNAL(clicked()), this, SLOT(startSettingsDialog()));
  QObject::connect((QObject*)PowerButton, SIGNAL(clicked()), this, SLOT(quit()));

  QObject::connect((QObject*)TuneUp, SIGNAL(clicked()), this, SLOT(incStation()));
  QObject::connect((QObject*)TuneDown, SIGNAL(clicked()), this, SLOT(decStation()));

  QObject::connect((QObject*)BankButton, SIGNAL(clicked()), this, SLOT(nextBank()));
  QObject::connect((QObject*)DescriptionButton, SIGNAL(clicked()), this, SLOT(setDescription()));

}

KMyRadio::~KMyRadio()
{
  tuner->mute(true);

}

void KMyRadio::setStation() {

  char buf[10];
  StationLabel->setText(gcvt(frequency, 5, (char*)&buf));
  tuner->setFreq(frequency);
  DescriptionButton->setText(config->readEntry(StationLabel->text()));
  return;
}

void KMyRadio::incStation() {

  if ( (frequency + 0.2) <= tuner->getFloatHighFreq()) {
    frequency += 0.2;
    setStation();
  }

}

void KMyRadio::decStation() {

  if ( (frequency - 0.2) >= tuner->getFloatLowFreq()) {
    frequency -= 0.2;
    setStation();
  }

}


void KMyRadio::fasttune() {

/*
  if (TuneUp->isDown())
    incStation();
  if (TuneDown->isDown())
    decStation();
*/

  if (Volume != LastVolume) {

    if (volumedevice == V4L_VOLUME) {
      tuner->setVolume(Volume);
    }
    else {
      mix->setVolume(volumedevice, Volume / 655);
    }

    LastVolume = Volume;

  }

}

void KMyRadio::handlePresets() {

  int check = -1;
  int x;

  if (Preset1->isDown())
    check = 0;
  if (Preset2->isDown())
    check = 1;
  if (Preset3->isDown())
    check = 2;
  if (Preset4->isDown())
    check = 3;
  if (Preset5->isDown())
    check = 4;
  if (Preset6->isDown())
    check = 5;

  if (check >= 0) {

     for (x = 0; x < 6; x++)
       if (check != x)
         PresetWatch[x] = 0;

     PresetWatch[check]++;

     if (PresetWatch[check] == 2)
       tuner->mute(true);

     if (PresetWatch[check] > 2) {
       Stations[(Bank-1)*6+check] = StationLabel->text();
       check = -1;
     }

  }

  if (check == -1) {

    for (x; x<6; x++)
      PresetWatch[x] = 0;

    if ( tuner->mute() ){
       delete tuner;
       tuner = new radiotuner("/dev/radio");
       setStation();
       tuner->setVolume(Volume);

    }


  }
}


void KMyRadio::setVolume(int v) {
  Volume = v;
}

void KMyRadio::preset(int p) {

  frequency = strtod(Stations[p], NULL);
  //DescriptionButton->setText(config->readEntry(Stations[p]));
  setStation();

}

void KMyRadio::preset1() {
  preset((Bank-1)*6 + 0);
}

void KMyRadio::preset2() {
  preset((Bank-1)*6 + 1);
}


void KMyRadio::preset3() {
  preset((Bank-1)*6 + 2);
}


void KMyRadio::preset4() {
  preset((Bank-1)*6 + 3);
}

void KMyRadio::preset5() {
  preset((Bank-1)*6 + 4);
}

void KMyRadio::preset6() {
  preset((Bank-1)*6 + 5);
}


void KMyRadio::readSettings() {

  Stations[0] = config->readEntry("p1");
  Stations[1] = config->readEntry("p2");
  Stations[2] = config->readEntry("p3");
  Stations[3] = config->readEntry("p4");
  Stations[4] = config->readEntry("p5");
  Stations[5] = config->readEntry("p6");
  Stations[6] = config->readEntry("p7");
  Stations[7] = config->readEntry("p8");
  Stations[8] = config->readEntry("p9");
  Stations[9] = config->readEntry("p10");
  Stations[10] = config->readEntry("p11");
  Stations[11] = config->readEntry("p12");
  Stations[12] = config->readEntry("p13");
  Stations[13] = config->readEntry("p14");
  Stations[14] = config->readEntry("p15");
  Stations[15] = config->readEntry("p16");
  Stations[16] = config->readEntry("p17");
  Stations[17] = config->readEntry("p18");


  StationFont = config->readFontEntry("stationfont");
     DescFont = config->readFontEntry("descriptionfont");
   ButtonFont = config->readFontEntry("buttonfont");

      BackColor = config->readColorEntry("backcolor");
   DisplayColor = config->readColorEntry("displaycolor");
   StationColor = config->readColorEntry("stationcolor");
      DescColor = config->readColorEntry("desccolor");
    ButtonColor = config->readColorEntry("buttoncolor");
ButtonTextColor = config->readColorEntry("buttontextcolor");
      ForeColor = config->readColorEntry("forecolor");

  OnExit = config->readNumEntry("onexit");

  DeviceName = config->readEntry("device");
  VolumeControlName = config->readEntry("volumecontrolname");
  for (int x=0;x<SOUND_MIXER_NRDEVICES;x++) {
    if (VolumeControlName == mixnames[x])
      volumedevice = x;
  }


}

void KMyRadio::writeSettings(bool defaultset = false) {
  if (defaultset)
    config->writeEntry("defaults", 1);
  else
    config->writeEntry("defaults", 0);

  config->writeEntry("p1", Stations[0]);
  config->writeEntry("p2", Stations[1]);
  config->writeEntry("p3", Stations[2]);
  config->writeEntry("p4", Stations[3]);
  config->writeEntry("p5", Stations[4]);
  config->writeEntry("p6", Stations[5]);
  config->writeEntry("p7", Stations[6]);
  config->writeEntry("p8", Stations[7]);
  config->writeEntry("p9", Stations[8]);
  config->writeEntry("p10", Stations[9]);
  config->writeEntry("p11", Stations[10]);
  config->writeEntry("p12", Stations[11]);
  config->writeEntry("p13", Stations[12]);
  config->writeEntry("p14", Stations[13]);
  config->writeEntry("p15", Stations[14]);
  config->writeEntry("p16", Stations[15]);
  config->writeEntry("p17", Stations[16]);
  config->writeEntry("p18", Stations[17]);

  //config->writeEntry("stationfont", StationLabel->font());
  //config->writeEntry("descriptionfont", DescriptionLabel->font());

  config->writeEntry("stationfont", StationFont);
  config->writeEntry("descriptionfont", DescFont);
  config->writeEntry("buttonfont", ButtonFont);

  config->writeEntry("backcolor", BackColor);
  config->writeEntry("displaycolor", DisplayColor);
  config->writeEntry("stationcolor", StationColor);
  config->writeEntry("desccolor", DescColor);
  config->writeEntry("buttoncolor", ButtonColor);
  config->writeEntry("buttontextcolor", ButtonTextColor);
  config->writeEntry("forecolor", ForeColor);

  config->writeEntry("onexit", OnExit);

  config->writeEntry("device", DeviceName);
  config->writeEntry("volumecontrolname", VolumeControlName);

  config->sync();

}

void KMyRadio::defaultSettings() {

  Stations[0] = "92.3";
  Stations[1] = "102.7";
  Stations[2] = "105.5";
  Stations[3] = "104.3";
  Stations[4] = "89.5";
  Stations[5] = "99.5";

  for (int x=6; x < 18; x ++) {
    Stations[x] = "92.3";
  }

  StationFont = StationLabel->font();
  DescFont = DescriptionButton->font();
  ButtonFont = Preset1->font();
  BackColor = QColor(129,129,129);
  ButtonColor = QColor(214,214,214);
  DescColor = QColor(105,6,6);
  DisplayColor = QColor(197,197,197);
  StationColor = QColor(0,0,0);

  DeviceName = "/dev/radio";
  volumedevice = V4L_VOLUME;
  VolumeControlName = "V4L";

  OnExit = EXIT_OFF;

  writeSettings(true);
}

void KMyRadio::initSettings() {

  settings->StationFont = StationFont;
  settings->DescFont = DescFont;
  settings->ButtonFont = ButtonFont;
  settings->StationFontButton->setText(StationFont.family());
  settings->DescFontButton->setText(DescFont.family());
  settings->ButtonFontButton->setText(ButtonFont.family());

  settings->BackColorButton->setColor(BackColor);
  settings->ButtonColorButton->setColor(ButtonColor);
  settings->DisplayColorButton->setColor(DisplayColor);
  settings->StationColorButton->setColor(StationColor);
  settings->DescColorButton->setColor(DescColor);
  settings->ForeColorButton->setColor(ForeColor);
  settings->ButtonFontColorButton->setColor(ButtonTextColor);

  settings->DeviceLine->setText(DeviceName);
  settings->MixerSetting->insertStringList(mixlist);

  if (volumedevice == V4L_VOLUME) {
    settings->MixerSetting->setEnabled(false);
    settings->V4LCheck->setChecked(true);
  }
  else {
    settings->MixerSetting->setEnabled(true);
    settings->V4LCheck->setChecked(false);
    int item = mixlist.findIndex(VolumeControlName);
    if (item == -1) {
      item = V4L_VOLUME;
      volumedevice = V4L_VOLUME;
    }
    settings->MixerSetting->setCurrentItem(item);
  }

  if (OnExit == EXIT_OFF) settings->RadioOff->setChecked(true);
  if (OnExit == EXIT_ON) settings->RadioOn->setChecked(true);
  if (OnExit == EXIT_ASK) settings->RadioAsk->setChecked(true);

}

void KMyRadio::applySettings() {

  StationLabel->setFont(StationFont);
  DescriptionButton->setFont(DescFont);

  Preset1->setFont(ButtonFont);
  Preset2->setFont(ButtonFont);
  Preset3->setFont(ButtonFont);
  Preset4->setFont(ButtonFont);
  Preset5->setFont(ButtonFont);
  Preset6->setFont(ButtonFont);
  TuneDown->setFont(ButtonFont);
  TuneUp->setFont(ButtonFont);
  BankButton->setFont(ButtonFont);
  PowerButton->setFont(ButtonFont);
  SetButton->setFont(ButtonFont);

  QPalette pal = palette();
  QColorGroup cg = pal.active();

  cg.setColor(QColorGroup::Background, BackColor);
  cg.setColor(QColorGroup::Button, ButtonColor);
  cg.setColor(QColorGroup::Foreground, ForeColor);
  cg.setColor(QColorGroup::ButtonText, ButtonTextColor);

  pal.setActive(cg);
  pal.setInactive(cg);
  setPalette(pal);

  pal = StationLabel->palette();
  cg = pal.active();

  cg.setColor(QColorGroup::Background, DisplayColor);
  cg.setColor(QColorGroup::Foreground, StationColor);

  pal.setActive(cg);
  pal.setInactive(cg);
  StationLabel->setPalette(pal);
  DescriptionButton->setPalette(pal);

  pal = DescriptionButton->palette();
  cg = pal.active();

  cg.setColor(QColorGroup::ButtonText, DescColor);
  cg.setColor(QColorGroup::Foreground, DisplayColor);
  cg.setColor(QColorGroup::Button, DisplayColor);

  pal.setActive(cg);
  pal.setInactive(cg);
  DescriptionButton->setPalette(pal);
  DescriptionButton->setFlat(true);

  pal = BankLabel->palette();
  cg = pal.active();
  cg.setColor(QColorGroup::Background, DisplayColor);
  pal.setActive(cg);
  pal.setInactive(cg);
  BankLabel->setPalette(pal);
  StereoLabel->setPalette(pal);



}


void KMyRadio::startSettingsDialog() {

  initSettings();

  if (settings->exec()) {

    StationFont = settings->StationFont;
    DescFont = settings->DescFont;
    ButtonFont = settings->ButtonFont;
    BackColor = settings->BackColorButton->color();
    StationColor = settings->StationColorButton->color();
    DescColor = settings->DescColorButton->color();
    DisplayColor = settings->DisplayColorButton->color();
    ButtonColor = settings->ButtonColorButton->color();
    ForeColor = settings->ForeColorButton->color();
    ButtonTextColor = settings->ButtonFontColorButton->color();

    DeviceName = settings->DeviceLine->text();

    if (settings->V4LCheck->isChecked()) {
      volumedevice = V4L_VOLUME;
      VolumeControlName = "V4L";
    }
    else {
      for (int x=0; x<SOUND_MIXER_NRDEVICES; x++) {
        if (mixnames[x] == settings->MixerSetting->currentText()) {
          volumedevice = x;
          VolumeControlName = settings->MixerSetting->currentText();
        }
      }
    }

    if (settings->RadioAsk->isChecked()) OnExit = EXIT_ASK;
    if (settings->RadioOn->isChecked()) OnExit = EXIT_ON;
    if (settings->RadioOff->isChecked()) OnExit = EXIT_OFF;

    applySettings();
    writeSettings();

  }

}

void KMyRadio::nextBank() {

  Bank++;
  if (Bank > 3)
    Bank = 1;

  char buf[10];
  BankLabel->setText(gcvt(Bank, 5, (char*)&buf));

}

void KMyRadio::setDescription() {

  QString desc = Ask("Question", "Enter Description", DescriptionButton->text());

  DescriptionButton->setText(desc);
  config->writeEntry(StationLabel->text(), desc);


}

void KMyRadio::quit() {

  if (OnExit == EXIT_OFF) {
    tuner->mute(true);
    kapp->quit();
  }
  else if (OnExit == EXIT_ON) {
    kapp->quit();
  }
  else {
    int answer = KMessageBox::warningYesNoCancel(0, "Leave the radio on?", "Question");
    if (answer == KMessageBox::Yes)
      kapp->quit();
    if (answer == KMessageBox::No) {
      tuner->mute(true);
      kapp->quit();
    }
  }


}

