/***************************************************************************
                          mixer.cpp  -  description
                             -------------------
    begin                : Sun Apr 15 2001
    copyright            : (C) 2001 by Chuck Ross
    email                : cross37@earthlink.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <linux/soundcard.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <unistd.h>
#include <iostream.h>
#include <errno.h>
#include <stdio.h>
#include "mixer.h"

Mixer::Mixer(){
  STATUS = init("/dev/mixer");
}

Mixer::Mixer(char *dev) {
  STATUS = init(dev);
}

Mixer::~Mixer(){
  close(FD);
}

int Mixer::init(char *dev) {

  FD = open(dev, O_RDWR);
  if (FD < 0) {
    cerr << "Error opening " << dev << "\n";
    perror("\0");
    STATUS = errno;
  }
  else {
    currentchannel = SOUND_MIXER_VOLUME;
    STATUS = OK;
    getMixerInfo();
    readDeviceMask();

    int i;
    for (i=0; i<SOUND_MIXER_NRDEVICES; i++)
     if (!(devmask & (1<<i))) {
      mixers[i]=false;
     }
     else {
      mixers[i]=true;
     }

    for (i=0; i<SOUND_MIXER_NRDEVICES; i++)
      cout << mixers[i] << "\n";

  }

  return STATUS;

}

void Mixer::getMixerInfo() {

  if (!ioctl(FD, SOUND_MIXER_INFO, &info)) {

  cout << "         ID: " << info.id << "\n";
  cout << "       Name: " << info.name << "\n";
  cout << "Mod Counter: " << info.modify_counter << "\n\n";

  }
}

void Mixer::readDeviceMask() {
  if (ioctl(FD, SOUND_MIXER_READ_DEVMASK, &devmask) < 0) {
     cout << "Cannot get Devices!!\n";

  }
}

int Mixer::getVolume() {
  int v;
  ioctl(FD, MIXER_READ(currentchannel), &v);
  return v;
}

int Mixer::getVolume(int ch) {
  int v;
  ioctl(FD, MIXER_READ(ch), &v);
  return v;
}

int Mixer::setVolume(int v) {
  int vol = v << 8;
  vol += v;
  ioctl(FD, MIXER_WRITE(currentchannel), &vol);
}

int Mixer::setVolume(int ch, int v) {
  int vol = v << 8;
  vol += v;
  ioctl(FD, MIXER_WRITE(ch), &vol);
}
	
int Mixer::getCurrentChannel() {
  return currentchannel;
}

void Mixer::setCurrentChannel(int ch) {
  currentchannel = ch;
}

bool Mixer::haveDevice(int device) {
  if ((device <= 0) && (device < SOUND_MIXER_NRDEVICES))
    return mixers[device];
  else
    return false;
}

void Mixer::temp() {
  devmask = 0;
  readDeviceMask();
/*
#define SOUND_MASK_VOLUME	(1 << SOUND_MIXER_VOLUME)
#define SOUND_MASK_BASS		(1 << SOUND_MIXER_BASS)
#define SOUND_MASK_TREBLE	(1 << SOUND_MIXER_TREBLE)
#define SOUND_MASK_SYNTH	(1 << SOUND_MIXER_SYNTH)
#define SOUND_MASK_PCM		(1 << SOUND_MIXER_PCM)
#define SOUND_MASK_SPEAKER	(1 << SOUND_MIXER_SPEAKER)
#define SOUND_MASK_LINE		(1 << SOUND_MIXER_LINE)
#define SOUND_MASK_MIC		(1 << SOUND_MIXER_MIC)
#define SOUND_MASK_CD		(1 << SOUND_MIXER_CD)
#define SOUND_MASK_IMIX		(1 << SOUND_MIXER_IMIX)
#define SOUND_MASK_ALTPCM	(1 << SOUND_MIXER_ALTPCM)
#define SOUND_MASK_RECLEV	(1 << SOUND_MIXER_RECLEV)
#define SOUND_MASK_IGAIN	(1 << SOUND_MIXER_IGAIN)
#define SOUND_MASK_OGAIN	(1 << SOUND_MIXER_OGAIN)
#define SOUND_MASK_LINE1	(1 << SOUND_MIXER_LINE1)
#define SOUND_MASK_LINE2	(1 << SOUND_MIXER_LINE2)
#define SOUND_MASK_LINE3	(1 << SOUND_MIXER_LINE3)
#define SOUND_MASK_DIGITAL1	(1 << SOUND_MIXER_DIGITAL1)
#define SOUND_MASK_DIGITAL2	(1 << SOUND_MIXER_DIGITAL2)
#define SOUND_MASK_DIGITAL3	(1 << SOUND_MIXER_DIGITAL3)
#define SOUND_MASK_PHONEIN	(1 << SOUND_MIXER_PHONEIN)
#define SOUND_MASK_PHONEOUT	(1 << SOUND_MIXER_PHONEOUT)
#define SOUND_MASK_RADIO	(1 << SOUND_MIXER_RADIO)
#define SOUND_MASK_VIDEO	(1 << SOUND_MIXER_VIDEO)
#define SOUND_MASK_MONITOR	(1 << SOUND_MIXER_MONITOR)
*/

  cout << devmask << "\n";
  if (devmask & 1<<SOUND_MIXER_VOLUME) cout << "Volume\n";
  if (devmask & 1<<SOUND_MIXER_BASS)   cout << "Bass\n";
  if (devmask & 1<<SOUND_MIXER_TREBLE) cout << "Treble\n";
  if (devmask & 1<<SOUND_MIXER_SYNTH) cout << "Synth\n";
  if (devmask & 1<<SOUND_MIXER_PCM) cout << "PCM\n";
  if (devmask & 1<<SOUND_MIXER_SPEAKER) cout << "Speaker\n";
  if (devmask & 1<<SOUND_MIXER_LINE) cout << "Line\n";
  if (devmask & 1<<SOUND_MIXER_MIC) cout << "Microphone\n";
  if (devmask & 1<<SOUND_MIXER_CD) cout << "CD\n";
  if (devmask & 1<<SOUND_MIXER_IMIX) cout << "IMIX\n";
  if (devmask & 1<<SOUND_MIXER_ALTPCM) cout << "Alt. PCM\n";
  if (devmask & 1<<SOUND_MIXER_RECLEV)   cout << "Record Level\n";
  if (devmask & 1<<SOUND_MIXER_IGAIN) cout << "IGAIN\n";
  if (devmask & 1<<SOUND_MIXER_OGAIN) cout << "OGAIN\n";
  if (devmask & 1<<SOUND_MIXER_LINE1) cout << "Line 1\n";
  if (devmask & 1<<SOUND_MIXER_LINE2) cout << "Line 2\n";
  if (devmask & 1<<SOUND_MIXER_LINE3) cout << "Line 3\n";
  if (devmask & 1<<SOUND_MIXER_MIC) cout << "Microphone\n";
  if (devmask & 1<<SOUND_MIXER_CD) cout << "CD\n";
  if (devmask & 1<<SOUND_MIXER_IMIX) cout << "IMIX\n";


}

